@@ -41,6 +41,11 @@ typedef void (*sig_handler)( int );
 #define strcasecmp stricmp
 #endif
 
+/* safe an extra header for lib/yesno.c exports. */
+int yesno(void);
+
+int cad_mkstemp(char *template);
+
 /* boolean */
 #define true 1
 #define false 0
