@@ -141,7 +141,7 @@ enum
     ELEM_supportedlock,
     ELEM_collection,
 
-    ELEM_ignore,
+    ELEM_ignore
 };
 
 static const struct ne_xml_idmap search_elements[] = {
