@@ -1,7 +1,8 @@
 /* 
    cadaver, command-line DAV client
    Copyright (C) 1999-2001, Joe Orton <joe@manyfish.co.uk>, 
-   except where otherwise indicated.
+   Portions are:
+   Copyright (C) 85, 88, 90, 91, 1995-1999 Free Software Foundation, Inc.
                                                                      
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,6 +22,7 @@
 
 #include "config.h"
 
+#include <time.h>
 #include <sys/types.h>
 
 #include <ne_basic.h>
@@ -54,3 +56,41 @@ enum resource_type getrestype(const char *uri)
     return ret;
 }
 
+
+char *format_time(time_t when)
+{
+    const char *fmt;
+    static char ret[256];
+    struct tm *local;
+    time_t current_time;
+    
+    if (when == (time_t)-1) {
+	/* Happens on lock-null resources */
+	return "  (unknown) ";
+    }
+
+    /* from GNU fileutils... this section is 
+     *  
+     */
+    current_time = time(NULL);
+    if (current_time > when + 6L * 30L * 24L * 60L * 60L	/* Old. */
+	|| current_time < when - 60L * 60L) {
+	/* The file is fairly old or in the future.  POSIX says the
+	   cutoff is 6 months old; approximate this by 6*30 days.
+	   Allow a 1 hour slop factor for what is considered "the
+	   future", to allow for NFS server/client clock disagreement.
+	   Show the year instead of the time of day.  */
+	fmt = "%b %e  %Y";
+    } else {
+	fmt = "%b %e %H:%M";
+    }
+
+    local = localtime(&when);
+    if (local != NULL) {
+	if (strftime(ret, 256, fmt, local)) {
+	    return ret;
+	}
+    }
+    return "???";
+}
+
