@@ -1,6 +1,6 @@
 /* 
    'version' for cadaver
-   Copyright (C) 2003, Joe Orton <joe@manyfish.co.uk>
+   Copyright (C) 2003-2004, Joe Orton <joe@manyfish.co.uk>
    Copyright (C) 2002-2003, GRASE Lab, UCSC <grase@cse.ucsc.edu>, 
                                                                      
    This program is free software; you can redistribute it and/or modify
@@ -100,7 +100,7 @@ enum
     ELEM_getcontentlength,
     ELEM_getlastmodified,
 
-    ELEM_ignore,
+    ELEM_ignore
 };
 
 
@@ -313,10 +313,12 @@ static void simple_request(const char *remote, const char *verb,
 	real_remote = ne_strdup(path);
     }
 
-    out_start(verb, real_remote);
+    out_start(verb, remote);
 
     req = ne_request_create(session, method, real_remote);
 
+    ne_lock_using_resource(req, real_remote, 0);
+
     ret = ne_request_dispatch(req);
     
     req_result(req, ret);
